from colav_protobuf import MissionRequest


def mission_request():
    """mocks a mission request proto message"""
    mission_request = MissionRequest()
    # Mission metadata
    mission_request.tag = "COLAV_MISSION_NORTH_BELFAST_TO_SOUTH_FRANCE"
    mission_request.mission_start_timestamp = (
        "1708353000"  # UNIX timestamp (epoch time in seconds)
    )

    # Static Vessel Information
    mission_request.vessel.tag = "EF12_WORKBOAT"
    mission_request.vessel.type = MissionRequest.Vessel.VesselType.HYDROFOIL
    mission_request.vessel.vessel_constraints.max_acceleration = 2.0
    mission_request.vessel.vessel_constraints.max_deceleration = -1.0
    mission_request.vessel.vessel_constraints.max_velocity = 30.0
    mission_request.vessel.vessel_constraints.min_velocity = 15.0
    mission_request.vessel.vessel_constraints.max_yaw_rate = 0.2
    mission_request.vessel.vessel_geometry.safety_threshold = 5

    # Earth-Centered, Earth-Fixed) Cartesian Coordinates North Belfast Lough in meters
    mission_request.mission_init_position.x = float(3, 675, 900.74)
    mission_request.mission_init_position.y = float(-372, 412.13)
    mission_request.mission_init_position.z = float(5, 181, 577.70)

    # Earth-Centered, Earth-Fixed) Cartesian Coordinates South France near Marseille in meters WON'T USE THIS METRIC IN LOCAL MOTION PLANNER! GOOD FOR GLOBAL PLANNING
    mission_request.mission_goal_position.x = float(4680627.4)
    mission_request.mission_goal_position.z = float(503, 374.5)
    mission_request.mission_goal_position.y = float(429, 9351.3)
    # Need to change vessel and obstacle geometry to just consider length and breadth

    # Acceptance radius in meters of the goal waypoint for autonomous navigation.
    mission_request.mission_goal_acceptance_radius = float(5.0)

    return mission_request



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: missionResponse.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='missionResponse.proto',
  package='colav',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15missionResponse.proto\x12\x05\x63olav\"\x90\x02\n\x0fMissionResponse\x12\x13\n\x0bmission_tag\x18\x01 \x02(\t\x12\x1f\n\x17mission_start_timestamp\x18\x02 \x02(\t\x12\x44\n\x10mission_response\x18\x03 \x02(\x0e\x32*.colav.MissionResponse.MissionResponseEnum\x12 \n\x18mission_response_details\x18\x04 \x02(\t\"_\n\x13MissionResponseEnum\x12\n\n\x06UNKOWN\x10\x00\x12\x14\n\x10MISSION_STARTING\x10\x01\x12\x11\n\rMISSION_ERROR\x10\x02\x12\x13\n\x0fMISSION_INVALID\x10\x03'
)



_MISSIONRESPONSE_MISSIONRESPONSEENUM = _descriptor.EnumDescriptor(
  name='MissionResponseEnum',
  full_name='colav.MissionResponse.MissionResponseEnum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISSION_STARTING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISSION_ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISSION_INVALID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=210,
  serialized_end=305,
)
_sym_db.RegisterEnumDescriptor(_MISSIONRESPONSE_MISSIONRESPONSEENUM)


_MISSIONRESPONSE = _descriptor.Descriptor(
  name='MissionResponse',
  full_name='colav.MissionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_tag', full_name='colav.MissionResponse.mission_tag', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_start_timestamp', full_name='colav.MissionResponse.mission_start_timestamp', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_response', full_name='colav.MissionResponse.mission_response', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_response_details', full_name='colav.MissionResponse.mission_response_details', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MISSIONRESPONSE_MISSIONRESPONSEENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=305,
)

_MISSIONRESPONSE.fields_by_name['mission_response'].enum_type = _MISSIONRESPONSE_MISSIONRESPONSEENUM
_MISSIONRESPONSE_MISSIONRESPONSEENUM.containing_type = _MISSIONRESPONSE
DESCRIPTOR.message_types_by_name['MissionResponse'] = _MISSIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MissionResponse = _reflection.GeneratedProtocolMessageType('MissionResponse', (_message.Message,), {
  'DESCRIPTOR' : _MISSIONRESPONSE,
  '__module__' : 'missionResponse_pb2'
  # @@protoc_insertion_point(class_scope:colav.MissionResponse)
  })
_sym_db.RegisterMessage(MissionResponse)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: obstaclesUpdate.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='obstaclesUpdate.proto',
  package='colav',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15obstaclesUpdate.proto\x12\x05\x63olav\"\xd0\x08\n\x0fObstaclesUpdate\x12\x13\n\x0bmission_tag\x18\x01 \x02(\t\x12\x41\n\x11\x64ynamic_obstacles\x18\x02 \x03(\x0b\x32&.colav.ObstaclesUpdate.DynamicObstacle\x12?\n\x10static_obstacles\x18\x03 \x03(\x0b\x32%.colav.ObstaclesUpdate.StaticObstacle\x12\x11\n\ttimestamp\x18\x04 \x02(\t\x12\x10\n\x08timestep\x18\x05 \x02(\t\x1aY\n\nObstacleID\x12\x0b\n\x03tag\x18\x01 \x02(\t\x12>\n\x04type\x18\x02 \x02(\x0e\x32#.colav.ObstaclesUpdate.ObstacleType:\x0bUNSPECIFIED\x1a\xe4\x01\n\x04Pose\x12\x36\n\x08position\x18\x01 \x02(\x0b\x32$.colav.ObstaclesUpdate.Pose.Position\x12<\n\x0borientation\x18\x02 \x02(\x0b\x32\'.colav.ObstaclesUpdate.Pose.Orientation\x1a+\n\x08Position\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\t\n\x01z\x18\x03 \x02(\x02\x1a\x39\n\x0bOrientation\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\t\n\x01z\x18\x03 \x02(\x02\x12\t\n\x01w\x18\x04 \x02(\x02\x1aV\n\x05State\x12)\n\x04pose\x18\x01 \x02(\x0b\x32\x1b.colav.ObstaclesUpdate.Pose\x12\x10\n\x08velocity\x18\x02 \x02(\x02\x12\x10\n\x08yaw_rate\x18\x03 \x02(\x02\x1a\\\n\x08Geometry\x12\x19\n\x11\x61\x63\x63\x65ptance_radius\x18\x01 \x02(\x02\x12\x35\n\x10polyshape_points\x18\x02 \x03(\x0b\x32\x1b.colav.ObstaclesUpdate.Pose\x1a\xa0\x01\n\x0f\x44ynamicObstacle\x12-\n\x02id\x18\x01 \x02(\x0b\x32!.colav.ObstaclesUpdate.ObstacleID\x12+\n\x05state\x18\x02 \x02(\x0b\x32\x1c.colav.ObstaclesUpdate.State\x12\x31\n\x08geometry\x18\x03 \x02(\x0b\x32\x1f.colav.ObstaclesUpdate.Geometry\x1a\x9d\x01\n\x0eStaticObstacle\x12-\n\x02id\x18\x01 \x02(\x0b\x32!.colav.ObstaclesUpdate.ObstacleID\x12)\n\x04pose\x18\x02 \x02(\x0b\x32\x1b.colav.ObstaclesUpdate.Pose\x12\x31\n\x08geometry\x18\x03 \x02(\x0b\x32\x1f.colav.ObstaclesUpdate.Geometry\"D\n\x0cObstacleType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\n\n\x06VESSEL\x10\x01\x12\r\n\tLAND_MASS\x10\x02\x12\x08\n\x04\x42UOY\x10\x03'
)



_OBSTACLESUPDATE_OBSTACLETYPE = _descriptor.EnumDescriptor(
  name='ObstacleType',
  full_name='colav.ObstaclesUpdate.ObstacleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VESSEL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LAND_MASS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUOY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1069,
  serialized_end=1137,
)
_sym_db.RegisterEnumDescriptor(_OBSTACLESUPDATE_OBSTACLETYPE)


_OBSTACLESUPDATE_OBSTACLEID = _descriptor.Descriptor(
  name='ObstacleID',
  full_name='colav.ObstaclesUpdate.ObstacleID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='colav.ObstaclesUpdate.ObstacleID.tag', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='colav.ObstaclesUpdate.ObstacleID.type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=331,
)

_OBSTACLESUPDATE_POSE_POSITION = _descriptor.Descriptor(
  name='Position',
  full_name='colav.ObstaclesUpdate.Pose.Position',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='colav.ObstaclesUpdate.Pose.Position.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='colav.ObstaclesUpdate.Pose.Position.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='colav.ObstaclesUpdate.Pose.Position.z', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=503,
)

_OBSTACLESUPDATE_POSE_ORIENTATION = _descriptor.Descriptor(
  name='Orientation',
  full_name='colav.ObstaclesUpdate.Pose.Orientation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='colav.ObstaclesUpdate.Pose.Orientation.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='colav.ObstaclesUpdate.Pose.Orientation.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='colav.ObstaclesUpdate.Pose.Orientation.z', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='w', full_name='colav.ObstaclesUpdate.Pose.Orientation.w', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=562,
)

_OBSTACLESUPDATE_POSE = _descriptor.Descriptor(
  name='Pose',
  full_name='colav.ObstaclesUpdate.Pose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='colav.ObstaclesUpdate.Pose.position', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='colav.ObstaclesUpdate.Pose.orientation', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBSTACLESUPDATE_POSE_POSITION, _OBSTACLESUPDATE_POSE_ORIENTATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=562,
)

_OBSTACLESUPDATE_STATE = _descriptor.Descriptor(
  name='State',
  full_name='colav.ObstaclesUpdate.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='colav.ObstaclesUpdate.State.pose', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='colav.ObstaclesUpdate.State.velocity', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw_rate', full_name='colav.ObstaclesUpdate.State.yaw_rate', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=564,
  serialized_end=650,
)

_OBSTACLESUPDATE_GEOMETRY = _descriptor.Descriptor(
  name='Geometry',
  full_name='colav.ObstaclesUpdate.Geometry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='acceptance_radius', full_name='colav.ObstaclesUpdate.Geometry.acceptance_radius', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polyshape_points', full_name='colav.ObstaclesUpdate.Geometry.polyshape_points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=744,
)

_OBSTACLESUPDATE_DYNAMICOBSTACLE = _descriptor.Descriptor(
  name='DynamicObstacle',
  full_name='colav.ObstaclesUpdate.DynamicObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='colav.ObstaclesUpdate.DynamicObstacle.id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='colav.ObstaclesUpdate.DynamicObstacle.state', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geometry', full_name='colav.ObstaclesUpdate.DynamicObstacle.geometry', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=747,
  serialized_end=907,
)

_OBSTACLESUPDATE_STATICOBSTACLE = _descriptor.Descriptor(
  name='StaticObstacle',
  full_name='colav.ObstaclesUpdate.StaticObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='colav.ObstaclesUpdate.StaticObstacle.id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose', full_name='colav.ObstaclesUpdate.StaticObstacle.pose', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geometry', full_name='colav.ObstaclesUpdate.StaticObstacle.geometry', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=910,
  serialized_end=1067,
)

_OBSTACLESUPDATE = _descriptor.Descriptor(
  name='ObstaclesUpdate',
  full_name='colav.ObstaclesUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_tag', full_name='colav.ObstaclesUpdate.mission_tag', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_obstacles', full_name='colav.ObstaclesUpdate.dynamic_obstacles', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_obstacles', full_name='colav.ObstaclesUpdate.static_obstacles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='colav.ObstaclesUpdate.timestamp', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestep', full_name='colav.ObstaclesUpdate.timestep', index=4,
      number=5, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBSTACLESUPDATE_OBSTACLEID, _OBSTACLESUPDATE_POSE, _OBSTACLESUPDATE_STATE, _OBSTACLESUPDATE_GEOMETRY, _OBSTACLESUPDATE_DYNAMICOBSTACLE, _OBSTACLESUPDATE_STATICOBSTACLE, ],
  enum_types=[
    _OBSTACLESUPDATE_OBSTACLETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=1137,
)

_OBSTACLESUPDATE_OBSTACLEID.fields_by_name['type'].enum_type = _OBSTACLESUPDATE_OBSTACLETYPE
_OBSTACLESUPDATE_OBSTACLEID.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_POSE_POSITION.containing_type = _OBSTACLESUPDATE_POSE
_OBSTACLESUPDATE_POSE_ORIENTATION.containing_type = _OBSTACLESUPDATE_POSE
_OBSTACLESUPDATE_POSE.fields_by_name['position'].message_type = _OBSTACLESUPDATE_POSE_POSITION
_OBSTACLESUPDATE_POSE.fields_by_name['orientation'].message_type = _OBSTACLESUPDATE_POSE_ORIENTATION
_OBSTACLESUPDATE_POSE.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_STATE.fields_by_name['pose'].message_type = _OBSTACLESUPDATE_POSE
_OBSTACLESUPDATE_STATE.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_GEOMETRY.fields_by_name['polyshape_points'].message_type = _OBSTACLESUPDATE_POSE
_OBSTACLESUPDATE_GEOMETRY.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_DYNAMICOBSTACLE.fields_by_name['id'].message_type = _OBSTACLESUPDATE_OBSTACLEID
_OBSTACLESUPDATE_DYNAMICOBSTACLE.fields_by_name['state'].message_type = _OBSTACLESUPDATE_STATE
_OBSTACLESUPDATE_DYNAMICOBSTACLE.fields_by_name['geometry'].message_type = _OBSTACLESUPDATE_GEOMETRY
_OBSTACLESUPDATE_DYNAMICOBSTACLE.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE_STATICOBSTACLE.fields_by_name['id'].message_type = _OBSTACLESUPDATE_OBSTACLEID
_OBSTACLESUPDATE_STATICOBSTACLE.fields_by_name['pose'].message_type = _OBSTACLESUPDATE_POSE
_OBSTACLESUPDATE_STATICOBSTACLE.fields_by_name['geometry'].message_type = _OBSTACLESUPDATE_GEOMETRY
_OBSTACLESUPDATE_STATICOBSTACLE.containing_type = _OBSTACLESUPDATE
_OBSTACLESUPDATE.fields_by_name['dynamic_obstacles'].message_type = _OBSTACLESUPDATE_DYNAMICOBSTACLE
_OBSTACLESUPDATE.fields_by_name['static_obstacles'].message_type = _OBSTACLESUPDATE_STATICOBSTACLE
_OBSTACLESUPDATE_OBSTACLETYPE.containing_type = _OBSTACLESUPDATE
DESCRIPTOR.message_types_by_name['ObstaclesUpdate'] = _OBSTACLESUPDATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ObstaclesUpdate = _reflection.GeneratedProtocolMessageType('ObstaclesUpdate', (_message.Message,), {

  'ObstacleID' : _reflection.GeneratedProtocolMessageType('ObstacleID', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_OBSTACLEID,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.ObstacleID)
    })
  ,

  'Pose' : _reflection.GeneratedProtocolMessageType('Pose', (_message.Message,), {

    'Position' : _reflection.GeneratedProtocolMessageType('Position', (_message.Message,), {
      'DESCRIPTOR' : _OBSTACLESUPDATE_POSE_POSITION,
      '__module__' : 'obstaclesUpdate_pb2'
      # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.Pose.Position)
      })
    ,

    'Orientation' : _reflection.GeneratedProtocolMessageType('Orientation', (_message.Message,), {
      'DESCRIPTOR' : _OBSTACLESUPDATE_POSE_ORIENTATION,
      '__module__' : 'obstaclesUpdate_pb2'
      # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.Pose.Orientation)
      })
    ,
    'DESCRIPTOR' : _OBSTACLESUPDATE_POSE,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.Pose)
    })
  ,

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_STATE,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.State)
    })
  ,

  'Geometry' : _reflection.GeneratedProtocolMessageType('Geometry', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_GEOMETRY,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.Geometry)
    })
  ,

  'DynamicObstacle' : _reflection.GeneratedProtocolMessageType('DynamicObstacle', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_DYNAMICOBSTACLE,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.DynamicObstacle)
    })
  ,

  'StaticObstacle' : _reflection.GeneratedProtocolMessageType('StaticObstacle', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESUPDATE_STATICOBSTACLE,
    '__module__' : 'obstaclesUpdate_pb2'
    # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate.StaticObstacle)
    })
  ,
  'DESCRIPTOR' : _OBSTACLESUPDATE,
  '__module__' : 'obstaclesUpdate_pb2'
  # @@protoc_insertion_point(class_scope:colav.ObstaclesUpdate)
  })
_sym_db.RegisterMessage(ObstaclesUpdate)
_sym_db.RegisterMessage(ObstaclesUpdate.ObstacleID)
_sym_db.RegisterMessage(ObstaclesUpdate.Pose)
_sym_db.RegisterMessage(ObstaclesUpdate.Pose.Position)
_sym_db.RegisterMessage(ObstaclesUpdate.Pose.Orientation)
_sym_db.RegisterMessage(ObstaclesUpdate.State)
_sym_db.RegisterMessage(ObstaclesUpdate.Geometry)
_sym_db.RegisterMessage(ObstaclesUpdate.DynamicObstacle)
_sym_db.RegisterMessage(ObstaclesUpdate.StaticObstacle)


# @@protoc_insertion_point(module_scope)



from .mission_request import MissionRequest
from .mission_response import MissionResponse
from .agent_update import AgentUpdate
from .obstacles_update import ObstaclesUpdate
from .controller_feedback import ControllerFeedback
import examples


__all__ = [
    "AgentUpdate",
    "ObstaclesUpdate",
    "MissionRequest",
    "MissionResponse",
    "ControllerFeedback",
    "examples",
]



from colav_protobuf import MissionResponse


def mission_response():
    """mocks a mission response proto message"""
    mission_response = MissionResponse()
    mission_response.mission_tag = "COLAV_MISSION_NORTH_BELFAST_TO_SOUTH_FRANCE"
    mission_response.mission_start_timestamp = "1708353005"
    mission_response.mission_response = MissionResponse.MissionResponseEnum.Value(
        "MISSION_STARTING"
    )
    mission_response.mission_response_details = (
        "Mission has started. Now Navigating to South France"
    )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: missionRequest.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='missionRequest.proto',
  package='colav',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14missionRequest.proto\x12\x05\x63olav\"\xf6\x06\n\x0eMissionRequest\x12\x0b\n\x03tag\x18\x01 \x02(\t\x12\x1f\n\x17mission_start_timestamp\x18\x02 \x02(\t\x12,\n\x06vessel\x18\x03 \x02(\x0b\x32\x1c.colav.MissionRequest.Vessel\x12:\n\x15mission_init_position\x18\x04 \x02(\x0b\x32\x1b.colav.MissionRequest.Point\x12:\n\x15mission_goal_position\x18\x05 \x02(\x0b\x32\x1b.colav.MissionRequest.Point\x12&\n\x1emission_goal_acceptance_radius\x18\x06 \x02(\x02\x1a(\n\x05Point\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x1a\xbd\x04\n\x06Vessel\x12\x0b\n\x03tag\x18\x01 \x02(\t\x12\x42\n\x04type\x18\x02 \x02(\x0e\x32\'.colav.MissionRequest.Vessel.VesselType:\x0bUNSPECIFIED\x12J\n\x12vessel_constraints\x18\x03 \x02(\x0b\x32..colav.MissionRequest.Vessel.VesselConstraints\x12\x44\n\x0fvessel_geometry\x18\x04 \x02(\x0b\x32+.colav.MissionRequest.Vessel.VesselGeometry\x1a\xb3\x01\n\x11VesselConstraints\x12\x18\n\x10max_acceleration\x18\x03 \x02(\x02\x12\x18\n\x10max_deceleration\x18\x04 \x02(\x02\x12\x14\n\x0cmax_velocity\x18\x05 \x02(\x02\x12\x14\n\x0cmin_velocity\x18\x06 \x02(\x02\x12\x14\n\x0cmax_yaw_rate\x18\x07 \x02(\x02\x1a(\n\x05Point\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\t\n\x01z\x18\x03 \x02(\x02\x1a\x61\n\x0eVesselGeometry\x12\x18\n\x10safety_threshold\x18\x01 \x01(\x02\x12\x35\n\x10polyshape_points\x18\x02 \x03(\x0b\x32\x1b.colav.MissionRequest.Point\"7\n\nVesselType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tHYDROFOIL\x10\x01\x12\t\n\x05OTHER\x10\x02'
)



_MISSIONREQUEST_VESSEL_VESSELTYPE = _descriptor.EnumDescriptor(
  name='VesselType',
  full_name='colav.MissionRequest.Vessel.VesselType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HYDROFOIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OTHER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=863,
  serialized_end=918,
)
_sym_db.RegisterEnumDescriptor(_MISSIONREQUEST_VESSEL_VESSELTYPE)


_MISSIONREQUEST_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='colav.MissionRequest.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='colav.MissionRequest.Point.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='colav.MissionRequest.Point.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='colav.MissionRequest.Point.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=342,
)

_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='colav.MissionRequest.Vessel.VesselConstraints.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='colav.MissionRequest.Vessel.VesselConstraints.Point.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='colav.MissionRequest.Vessel.VesselConstraints.Point.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='colav.MissionRequest.Vessel.VesselConstraints.Point.z', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=722,
  serialized_end=762,
)

_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS = _descriptor.Descriptor(
  name='VesselConstraints',
  full_name='colav.MissionRequest.Vessel.VesselConstraints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_acceleration', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_acceleration', index=0,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_deceleration', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_deceleration', index=1,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_velocity', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_velocity', index=2,
      number=5, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_velocity', full_name='colav.MissionRequest.Vessel.VesselConstraints.min_velocity', index=3,
      number=6, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_yaw_rate', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_yaw_rate', index=4,
      number=7, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS_POINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=762,
)

_MISSIONREQUEST_VESSEL_VESSELGEOMETRY = _descriptor.Descriptor(
  name='VesselGeometry',
  full_name='colav.MissionRequest.Vessel.VesselGeometry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='safety_threshold', full_name='colav.MissionRequest.Vessel.VesselGeometry.safety_threshold', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polyshape_points', full_name='colav.MissionRequest.Vessel.VesselGeometry.polyshape_points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=764,
  serialized_end=861,
)

_MISSIONREQUEST_VESSEL = _descriptor.Descriptor(
  name='Vessel',
  full_name='colav.MissionRequest.Vessel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='colav.MissionRequest.Vessel.tag', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='colav.MissionRequest.Vessel.type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vessel_constraints', full_name='colav.MissionRequest.Vessel.vessel_constraints', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vessel_geometry', full_name='colav.MissionRequest.Vessel.vessel_geometry', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS, _MISSIONREQUEST_VESSEL_VESSELGEOMETRY, ],
  enum_types=[
    _MISSIONREQUEST_VESSEL_VESSELTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=345,
  serialized_end=918,
)

_MISSIONREQUEST = _descriptor.Descriptor(
  name='MissionRequest',
  full_name='colav.MissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='colav.MissionRequest.tag', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_start_timestamp', full_name='colav.MissionRequest.mission_start_timestamp', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vessel', full_name='colav.MissionRequest.vessel', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_init_position', full_name='colav.MissionRequest.mission_init_position', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_goal_position', full_name='colav.MissionRequest.mission_goal_position', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_goal_acceptance_radius', full_name='colav.MissionRequest.mission_goal_acceptance_radius', index=5,
      number=6, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MISSIONREQUEST_POINT, _MISSIONREQUEST_VESSEL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32,
  serialized_end=918,
)

_MISSIONREQUEST_POINT.containing_type = _MISSIONREQUEST
_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS_POINT.containing_type = _MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS
_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS.containing_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST_VESSEL_VESSELGEOMETRY.fields_by_name['polyshape_points'].message_type = _MISSIONREQUEST_POINT
_MISSIONREQUEST_VESSEL_VESSELGEOMETRY.containing_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST_VESSEL.fields_by_name['type'].enum_type = _MISSIONREQUEST_VESSEL_VESSELTYPE
_MISSIONREQUEST_VESSEL.fields_by_name['vessel_constraints'].message_type = _MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS
_MISSIONREQUEST_VESSEL.fields_by_name['vessel_geometry'].message_type = _MISSIONREQUEST_VESSEL_VESSELGEOMETRY
_MISSIONREQUEST_VESSEL.containing_type = _MISSIONREQUEST
_MISSIONREQUEST_VESSEL_VESSELTYPE.containing_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST.fields_by_name['vessel'].message_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST.fields_by_name['mission_init_position'].message_type = _MISSIONREQUEST_POINT
_MISSIONREQUEST.fields_by_name['mission_goal_position'].message_type = _MISSIONREQUEST_POINT
DESCRIPTOR.message_types_by_name['MissionRequest'] = _MISSIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MissionRequest = _reflection.GeneratedProtocolMessageType('MissionRequest', (_message.Message,), {

  'Point' : _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
    'DESCRIPTOR' : _MISSIONREQUEST_POINT,
    '__module__' : 'missionRequest_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionRequest.Point)
    })
  ,

  'Vessel' : _reflection.GeneratedProtocolMessageType('Vessel', (_message.Message,), {

    'VesselConstraints' : _reflection.GeneratedProtocolMessageType('VesselConstraints', (_message.Message,), {

      'Point' : _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
        'DESCRIPTOR' : _MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS_POINT,
        '__module__' : 'missionRequest_pb2'
        # @@protoc_insertion_point(class_scope:colav.MissionRequest.Vessel.VesselConstraints.Point)
        })
      ,
      'DESCRIPTOR' : _MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS,
      '__module__' : 'missionRequest_pb2'
      # @@protoc_insertion_point(class_scope:colav.MissionRequest.Vessel.VesselConstraints)
      })
    ,

    'VesselGeometry' : _reflection.GeneratedProtocolMessageType('VesselGeometry', (_message.Message,), {
      'DESCRIPTOR' : _MISSIONREQUEST_VESSEL_VESSELGEOMETRY,
      '__module__' : 'missionRequest_pb2'
      # @@protoc_insertion_point(class_scope:colav.MissionRequest.Vessel.VesselGeometry)
      })
    ,
    'DESCRIPTOR' : _MISSIONREQUEST_VESSEL,
    '__module__' : 'missionRequest_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionRequest.Vessel)
    })
  ,
  'DESCRIPTOR' : _MISSIONREQUEST,
  '__module__' : 'missionRequest_pb2'
  # @@protoc_insertion_point(class_scope:colav.MissionRequest)
  })
_sym_db.RegisterMessage(MissionRequest)
_sym_db.RegisterMessage(MissionRequest.Point)
_sym_db.RegisterMessage(MissionRequest.Vessel)
_sym_db.RegisterMessage(MissionRequest.Vessel.VesselConstraints)
_sym_db.RegisterMessage(MissionRequest.Vessel.VesselConstraints.Point)
_sym_db.RegisterMessage(MissionRequest.Vessel.VesselGeometry)


# @@protoc_insertion_point(module_scope)



from colav_protobuf import AgentUpdate


def agent_update():
    """mocks a agent update proto message"""
    agent_update = AgentUpdate()
    agent_update.mission_tag = "COLAV_MISSION_NORTH_BELFAST_TO_SOUTH_FRANCE"
    agent_update.agent_tag = "EF12_WORKBOAT"
    agent_update.state.pose.position.x = float(3_675_830.74)
    agent_update.state.pose.position.y = float(-272_412.13)
    agent_update.state.pose.position.z = float(4_181_577.70)
    agent_update.state.pose.orientation.x = 0
    agent_update.state.pose.orientation.y = 0
    agent_update.state.pose.orientation.z = 0
    agent_update.state.pose.orientation.w = 1

    agent_update.state.velocity = 20
    agent_update.state.yaw_rate = 0.2
    agent_update.state.acceleration = 1

    agent_update.timestamp = "1708853235"
    agent_update.timestep = "000000000012331"

    return agent_update



from colav_protobuf import ControllerFeedback


def controller_feedback():
    """mocks controller feedback"""
    controller_feedback = ControllerFeedback()
    controller_feedback.mission_tag = "COLAV_MISSION_NORTH_BELFAST_TO_SOUTH_FRANCE"
    controller_feedback.agent_tag = "EF12_WORKBOAT"
    controller_feedback.ctrl_mode = ControllerFeedback.CTRLMode.Value("CRUISE")
    controller_feedback.ctrl_status = ControllerFeedback.CTRLStatus.Value("ACTIVE")
    controller_feedback.ctrl_cmd.velocity = float(15.0)
    controller_feedback.ctrl_cmd.yaw_rate = float(0.2)

    controller_feedback.timestamp = "1708853235"
    controller_feedback.timestep = "000000000012331"

    return controller_feedback
